Crate mkutils

Crate mkutils 

Macros

loop_selectasync
trace
when

Structs

ActiveVec
Atomtui
Atomstui
Chunktui
Debugged
Distancetui
Eventasync
ExtendedGraphemeItertui
Indexed
KeyBindingtui
KeyMaptui
KeyMapSessiontui
KeyMapStatetui
Linetui
Linestui
NumExtendedGraphemestui
NumNewlinestui
OptionDisplay
Pointtui
Processasync
ProcessBuilderasync
ReadValue
ResultDisplay
Rgbtui
Ropetui
RopeBuildertui
Screentui
ScreenConfigtui
ScrollViewStatetui
Socketasync and unstable and serde
Terminaltui
Timertracing
Timestamped
Tracingtracing

Enums

Orientationtui
Outputunstable
ScrollCountTypetui
ScrollWhentui

Traits

Requestasync and unstable and serde
ScrollViewtui
Transposetui
Utils

Type Aliases

KeyBindingTrietui
KeyMapIncSearchtui
PointU16tui
PointUsizetui
ScreenTerminaltui
Stdouttui

Attribute Macros

context
main
Example

Derive Macros

Constructor
Adds a new() constructor that accepts each field as a parameter. The method is private by default. Use #[new("pub")] or #[new("pub(crate)")] to set a custom visibility.
Default
Implements Default for a struct, using Default::default() for each field unless a #[default(...)] attribute provides a custom expression.
FromChain
Implement ::std::convert::From through a chain of intermediate types.
SaturatingAdd
Implements num::traits::SaturatingAdd for a struct by delegating to each field.
SaturatingSub
Implements num::traits::SaturatingSub for a struct by delegating to each field.
SetVariant
Adds set_*() methods for each unit variant on the given enum.
Toggle
Adds a toggled() method that maps each enum variant to the next unit variant.
TypeAssoc
Implements traits that only have associated types.