Macros
- loop_
select async - trace
- when
Structs
- Active
Vec - Atom
tui - Atoms
tui - Chunk
tui - Debugged
- Distance
tui - Event
async - Extended
Grapheme Iter tui - Indexed
- KeyBinding
tui - KeyMap
tui - KeyMap
Session tui - KeyMap
State tui - Line
tui - Lines
tui - NumExtended
Graphemes tui - NumNewlines
tui - Option
Display - Point
tui - Process
async - Process
Builder async - Read
Value - Result
Display - Rgb
tui - Rope
tui - Rope
Builder tui - Screen
tui - Screen
Config tui - Scroll
View State tui - Socket
asyncandunstableandserde-extra - Terminal
tui - Timer
tracing - Timestamped
- Tracing
tracing
Enums
- Orientation
tui - Output
unstable - Scroll
Count Type tui - Scroll
When tui
Traits
- Request
asyncandunstableandserde-extra - Scroll
View tui - Transpose
tui - Utils
Type Aliases
- KeyBinding
Trie tui - KeyMap
IncSearch tui - Point
U16 tui - Point
Usize tui - Screen
Terminal tui - Stdout
tui
Attribute Macros
Derive Macros
- Constructor
- Adds a
new()constructor that accepts each field as a parameter. The method is private by default. Use#[new("pub")]or#[new("pub(crate)")]to set a custom visibility. - Default
- Implements
Defaultfor a struct, usingDefault::default()for each field unless a#[default(...)]attribute provides a custom expression. - From
Chain - Implement
::std::convert::Fromthrough a chain of intermediate types. - Saturating
Add - Implements
num::traits::SaturatingAddfor a struct by delegating to each field. - Saturating
Sub - Implements
num::traits::SaturatingSubfor a struct by delegating to each field. - SetVariant
- Adds
set_*()methods for each unit variant on the given enum. - Toggle
- Adds a
toggled()method that maps each enum variant to the next unit variant. - Type
Assoc - Implements traits that only have associated types.