Macros
- loop_
select async - trace
- when
Structs
- Active
Vec misc - Debugged
fmt - Event
async - Indexed
misc - KeyBinding
tui - KeyMap
tui - KeyMap
Session tui - KeyMap
State tui - Option
Display fmt - Point
ropeyortui - Process
process - Process
Builder process - Read
Value async - Result
Display fmt - Rgb
tui - Rope
Builder ropey - Screen
tui - Screen
Config tui - Scroll
View tui - Scroll
View State tui - Socket
socket - Terminal
tui - Timestamped
misc - Tracing
tracing
Enums
- Orientation
ropeyortui - Output
output - Scroll
Count Type tui - Scroll
When tui
Traits
Type Aliases
- KeyBinding
Trie tui - KeyMap
IncSearch tui - Point
U16 ropeyortui - Point
Usize ropeyortui - Screen
Terminal tui - Stdout
tui
Attribute Macros
- context
mkutils-macros
Derive Macros
- Default
mkutils-macros - Implements
Defaultfor a struct, usingDefault::default()for each field unless a#[default(...)]attribute provides a custom expression. - From
Chain mkutils-macros - Implement
::std::convert::Fromthrough a chain of intermediate types. - Inner
mkutils-macros - Adds an
inner()method that returns a copy of the wrapped type. - Saturating
Add mkutils-macros - Implements
num::traits::SaturatingAddfor a struct by delegating to each field. - Saturating
Sub mkutils-macros - Implements
num::traits::SaturatingSubfor a struct by delegating to each field. - SetVariant
mkutils-macros - Adds
set_*()methods for each unit variant on the given enum. - Toggle
mkutils-macros - Adds a
toggled()method that maps each enum variant to the next unit variant. - Type
Assoc mkutils-macros - Implements traits that only have associated types.