Crate mkutils

Crate mkutils 

Macros

loop_selectasync
trace
when

Structs

ActiveVecmisc
Debuggedfmt
Eventasync
Indexedmisc
KeyBindingtui
KeyMaptui
KeyMapSessiontui
KeyMapStatetui
OptionDisplayfmt
Pointropey or tui
Processprocess
ProcessBuilderprocess
ReadValueasync
ResultDisplayfmt
Rgbtui
RopeBuilderropey
Screentui
ScreenConfigtui
ScrollViewtui
ScrollViewStatetui
Socketsocket
Terminaltui
Timestampedmisc
Tracingtracing

Enums

Orientationropey or tui
Outputoutput
ScrollCountTypetui
ScrollWhentui

Traits

Contenttui
Requestsocket
Transposeropey or tui
Utils

Type Aliases

KeyBindingTrietui
KeyMapIncSearchtui
PointU16ropey or tui
PointUsizeropey or tui
ScreenTerminaltui
Stdouttui

Attribute Macros

contextmkutils-macros

Derive Macros

Defaultmkutils-macros
Implements Default for a struct, using Default::default() for each field unless a #[default(...)] attribute provides a custom expression.
FromChainmkutils-macros
Implement ::std::convert::From through a chain of intermediate types.
Innermkutils-macros
Adds an inner() method that returns a copy of the wrapped type.
SaturatingAddmkutils-macros
Implements num::traits::SaturatingAdd for a struct by delegating to each field.
SaturatingSubmkutils-macros
Implements num::traits::SaturatingSub for a struct by delegating to each field.
SetVariantmkutils-macros
Adds set_*() methods for each unit variant on the given enum.
Togglemkutils-macros
Adds a toggled() method that maps each enum variant to the next unit variant.
TypeAssocmkutils-macros
Implements traits that only have associated types.